@@ -125,7 +125,8 @@ describe('Main', () => {
         </TestWrapper>,
       );
 
-      expect(screen.queryByText('Pod/Container')).not.toBeInTheDocument();
+      expect(screen.queryByText('Pod')).not.toBeInTheDocument();
+      expect(screen.queryByText('Container')).not.toBeInTheDocument();
       expect(screen.queryByText('Region')).not.toBeInTheDocument();
       expect(screen.queryByText('Node')).not.toBeInTheDocument();
     });
@@ -141,7 +142,8 @@ describe('Main', () => {
       );
 
       expect(screen.getByText('Timestamp')).toBeInTheDocument();
-      expect(screen.getByText('Pod/Container')).toBeInTheDocument();
+      expect(screen.getByText('Pod')).toBeInTheDocument();
+      expect(screen.getByText('Container')).toBeInTheDocument();
       expect(screen.getByText('Region')).toBeInTheDocument();
       expect(screen.getByText('Zone')).toBeInTheDocument();
       expect(screen.getByText('OS')).toBeInTheDocument();
@@ -149,6 +151,21 @@ describe('Main', () => {
       expect(screen.getByText('Node')).toBeInTheDocument();
       expect(screen.getByText('Message')).toBeInTheDocument();
     });
+
+    it('renders columns in the order they appear in visibleColsAtom', () => {
+      const store = createStore();
+      // Pod before Timestamp — reversed from ALL_VIEWER_COLUMNS order
+      store.set(visibleColsAtom, new Set([ViewerColumn.Pod, ViewerColumn.Timestamp, ViewerColumn.Message]));
+
+      render(
+        <TestWrapper store={store}>
+          <Main />
+        </TestWrapper>,
+      );
+
+      const colIds = [...document.querySelectorAll('[data-col-id]')].map((el) => el.getAttribute('data-col-id'));
+      expect(colIds).toEqual([ViewerColumn.Pod, ViewerColumn.Timestamp, ViewerColumn.Message]);
+    });
   });
 
   describe('LogViewer integration', () => {
