@@ -25,7 +25,7 @@ import { cn, cssEncode } from '@/lib/util';
 import { LogViewer, useLogViewerState } from '@/components/widgets/log-viewer';
 import type { LogRecord, LogViewerInitialPosition, LogViewerVirtualRow } from '@/components/widgets/log-viewer';
 
-import { ALL_VIEWER_COLUMNS, PageContext, ViewerColumn } from './shared';
+import { PageContext, ViewerColumn } from './shared';
 import { isFollowAtom, isWrapAtom, visibleColsAtom } from './state';
 
 const DEFAULT_INITIAL_POSITION = { type: 'tail' } satisfies LogViewerInitialPosition;
@@ -93,6 +93,7 @@ function newDefaultWidths() {
 
 function useMeasureWidths() {
   const [widths, setWidths] = useState(newDefaultWidths);
+  const [triggerID, setTriggerID] = useState(0);
 
   const pendingRef = useRef(null) as unknown as React.RefObject<typeof widths>;
   if (!pendingRef.current) pendingRef.current = newDefaultWidths();
@@ -134,7 +135,7 @@ function useMeasureWidths() {
         flush();
       }
     },
-    [flush],
+    [flush, triggerID],
   );
 
   const measureCellElement = useCallback(
@@ -151,7 +152,7 @@ function useMeasureWidths() {
         flush();
       }
     },
-    [flush],
+    [flush, triggerID],
   );
 
   const resetWidths = useCallback(() => {
@@ -162,6 +163,7 @@ function useMeasureWidths() {
     pendingRef.current = newDefaultWidths();
     measuredRef.current = new WeakSet();
     setWidths(newDefaultWidths);
+    setTriggerID((id) => id + 1);
   }, []);
 
   return { widths, measureRowElement, measureCellElement, resetWidths };
@@ -314,22 +316,19 @@ const HeaderRow = ({
           minWidth: isWrap ? '100%' : maxRowWidth || '100%',
         }}
       >
-        {ALL_VIEWER_COLUMNS.map((col) => {
-          if (visibleCols.has(col)) {
-            const minWidth = isWrap && col === ViewerColumn.Message ? undefined : colWidths.get(col);
-            return (
-              <div
-                key={col}
-                ref={measureCellElement}
-                data-col-id={col}
-                className="whitespace-nowrap uppercase px-2 flex items-center text-xs"
-                style={minWidth ? { minWidth: `${minWidth}px` } : undefined}
-              >
-                {col !== ViewerColumn.ColorDot && col}
-              </div>
-            );
-          }
-          return null;
+        {[...visibleCols].map((col) => {
+          const minWidth = isWrap && col === ViewerColumn.Message ? undefined : colWidths.get(col);
+          return (
+            <div
+              key={col}
+              ref={measureCellElement}
+              data-col-id={col}
+              className="whitespace-nowrap uppercase px-2 flex items-center text-xs"
+              style={minWidth ? { minWidth: `${minWidth}px` } : undefined}
+            >
+              {col !== ViewerColumn.ColorDot && col}
+            </div>
+          );
         })}
       </div>
     </div>
@@ -351,8 +350,10 @@ const getAttribute = (record: LogRecord, col: ViewerColumn) => {
       const el = <div className="inline-block w-2 h-2 rounded-full" style={{ backgroundColor: `var(--${k}-color)` }} />;
       return el;
     }
-    case ViewerColumn.PodContainer:
-      return `${record.source.podName}/${record.source.containerName}`;
+    case ViewerColumn.Pod:
+      return record.source.podName;
+    case ViewerColumn.Container:
+      return record.source.containerName;
     case ViewerColumn.Region:
       return record.source.metadata.region;
     case ViewerColumn.Zone:
@@ -395,27 +396,25 @@ const RecordRow = memo(
     measureCellElement,
   }: RecordRowProps) => {
     const els: React.ReactElement[] = [];
-    ALL_VIEWER_COLUMNS.forEach((col) => {
-      if (visibleCols.has(col)) {
-        const minWidth = isWrap && col === ViewerColumn.Message ? undefined : colWidths.get(col);
-        const shouldWrap = isWrap && col === ViewerColumn.Message;
-        els.push(
-          <div
-            key={col}
-            ref={measureCellElement}
-            data-col-id={col}
-            className={cn(
-              row.index % 2 !== 0 && 'bg-chrome-100',
-              'px-2',
-              shouldWrap ? 'whitespace-pre-wrap wrap-break-word' : 'whitespace-nowrap',
-              col === ViewerColumn.Timestamp ? 'bg-chrome-200' : '',
-            )}
-            style={minWidth ? { minWidth: `${minWidth}px` } : undefined}
-          >
-            {getAttribute(row.record, col)}
-          </div>,
-        );
-      }
+    visibleCols.forEach((col) => {
+      const minWidth = isWrap && col === ViewerColumn.Message ? undefined : colWidths.get(col);
+      const shouldWrap = isWrap && col === ViewerColumn.Message;
+      els.push(
+        <div
+          key={col}
+          ref={measureCellElement}
+          data-col-id={col}
+          className={cn(
+            row.index % 2 !== 0 && 'bg-chrome-100',
+            'px-2',
+            shouldWrap ? 'whitespace-pre-wrap wrap-break-word' : 'whitespace-nowrap',
+            col === ViewerColumn.Timestamp ? 'bg-chrome-200' : '',
+          )}
+          style={minWidth ? { minWidth: `${minWidth}px` } : undefined}
+        >
+          {getAttribute(row.record, col)}
+        </div>,
+      );
     });
 
     return (
@@ -474,11 +473,12 @@ export const Main = () => {
   const visibleCols = useAtomValue(visibleColsAtom);
 
   // Generate grid template
-  const gridTemplate = useMemo(() => {
-    const visibleColumns = ALL_VIEWER_COLUMNS.filter((col) => visibleCols.has(col));
-    // Keep natural sizing - let cells determine column width
-    return visibleColumns.map((col) => (col === ViewerColumn.Message ? '1fr' : 'auto')).join(' ');
-  }, [visibleCols]);
+  const gridTemplate = useMemo(
+    () =>
+      // Keep natural sizing - let cells determine column width
+      [...visibleCols].map((col) => (col === ViewerColumn.Message ? '1fr' : 'auto')).join(' '),
+    [visibleCols],
+  );
 
   // Reset column widths when loading new data
   useEffect(() => {
